C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE ucase (lstr, ustr)

C @(#)Subroutine: ucase              Author: R.A. Jansen -- Jul 29, 2008
C @(#)
C @(#)  Purpose: Copy as many characters of an input string as will  fit
C @(#)    in the output string, while converting alphabetical characters
C @(#)    to upper case.  Input and output  strings  are allowed to have
C @(#)    different declared lengths; if the output string is longer, it
C @(#)    will be padded to the right with blanks.  The input and output
C @(#)    strings are allowed to map onto the same named variable in the
C @(#)    calling routine.
C @(#)
C @(#)  Calling sequence:
C @(#)     CALL ucase (lstr, ustr),  where 'lstr' and 'ustr' are charac-
C @(#)     ter strings of arbitrary declared length that possibly may be
C @(#)     identical.
C @(#)
C @(#)  Note: since the character collating sequence  might  conceivably
C @(#)     be machine and compiler dependent, we test explicitly against
C @(#)     ICHAR('a'), ICHAR('z'), and ICHAR('A'). Should garbage result
C @(#)     anyway,  try ACHAR and IACHAR  instead of CHAR and ICHAR,  or
C @(#)     try the logical functions LGE and LLE instead of GE and LE.
C @(#)
C @(#)  Dependencies:     cinit, clen
C @(#)
C @(#)  Revision history:
C @(#)    May 14, 1999 [RAJ] -- Original version ('firat' project)
C @(#)    Oct 25, 2000 [RAJ] -- alternative to  in-place  conversion  in
C @(#)                          original routine,  so we can preserve  a
C @(#)                          copy of the original string; single call
C @(#)                          allows uppercasing & truncation/padding.
C @(#)    Jul 29, 2008 [RAJ] -- expanded documentation of this routine.
C @(#)    Oct  5, 2009 [RAJ] -- change to allow input & output string to
C @(#)                          map onto same named variable in calling
C @(#)                          routine (conditional call to 'cinit').
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER*(*) lstr, ustr

C --- Declaration of local variables...
      INTEGER   mlen, clen, i, j

C --- Initialize output string (if different from input) with blanks...
      IF (ustr.NE.lstr) CALL cinit(ustr)

C --- Determine declared length of shortest of the two strings...
      mlen = MIN(LEN(lstr),LEN(ustr))

C --- Copy (possibly truncate) input string to output string...
      ustr(1:mlen) = lstr(1:mlen)

C --- Convert any lower case alphabetical characters in the output
C     string to upper case...
      DO i=1,MIN(mlen,clen(lstr))
         j = ICHAR(lstr(i:i))
         IF (j.GE.ICHAR('a').AND.j.LE.ICHAR('z')) THEN
C           we found a lower case alphabetical character; convert it...
            ustr(i:i) = CHAR(j-ICHAR('a')+ICHAR('A'))
         ENDIF
      ENDDO

      RETURN
      END


