C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE wsizstr(styp,naxes,axlen,sizstr,ierr)

C @(#)Subroutine: wsizstr            Author: R.A. Jansen -- Oct 25, 2000
C @(#)
C @(#)  Purpose: given the number of axes in a data array and the length
C @(#)    (number of elements) of each axis and given a format specifier
C @(#)    'styp', return a data array dimension text string as:
C @(#)
C @(#)    styp=0 (default) :  "[axlen1,axlen2,...,axlenN]"   (N=naxes)
C @(#)    styp=1           :  "axlen1*axlen2*...*axlenN"     (N=naxes)
C @(#)
C @(#)  Calling sequence: CALL wsizstr(styp,naxes,axlen,sizstr,ierr)   ,
C @(#)    where 'styp'  is an integer with valid values 0 and 1, 'naxes'
C @(#)    is the integer number of axes in the data array and 'axlen' an
C @(#)    integer array of 'naxes' axis lengths  (e.g., number of pixels
C @(#)    along each image axis. Character string 'sizstr' has arbitrary
C @(#)    declared length and will return the formatted text string, and
C @(#)    and integer flag 'ierr' will be non-zero upon exit  should any
C @(#)    error condition be triggered.
C @(#)
C @(#)  Dependencies:     cinit, clen
C @(#)
C @(#)  Revision history:
C @(#)    May 24, 2008 [RAJ] -- expanded documentation.
C @(#)    Aug  3, 2008 [RAJ] -- changed explicit to variable formatting;
C @(#)                          moved 'styp' to be the first variable in
C @(#)                          the calling sequence.
C @(#)    Aug 31, 2008 [RAJ] -- generalized routine  to accomodate  data
C @(#)                          arrays of arbitrary dimension.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER*(*) sizstr
      INTEGER	naxes, axlen(*), styp, ierr

C --- Declaration of local variables...
      CHARACTER	ctmp*80, cch*1, fmt*8
      INTEGER	i, j, clen


C --- Initialize...
      CALL cinit(sizstr)

C --- Return for non-zero input error status, trivial or bad input...
      IF (ierr.NE.0) RETURN
      IF (styp.LT.0.OR.styp.GT.1) styp = 0
      IF (naxes.EQ.0) THEN
         sizstr = '[0]'
         RETURN
      ENDIF
      DO j=1,naxes
         IF (axlen(j).LT.0) ierr = 1
         IF (ierr.NE.0) RETURN
      ENDDO

C --- Check whether 'sizstr' is long enough to hold the image size...
      i = 2
      IF (styp.EQ.1) i = 0
      DO j=1,naxes
         i = i + INT(LOG10(FLOAT(axlen(j)))) + 1
      ENDDO
      IF (i.GT.LEN(sizstr)) ierr = 2
      IF (ierr.NE.0) RETURN

C --- Format will be either [ncol,nrow,..] or 'ncolxnrowx..' ...
      IF (styp.EQ.0) THEN
         sizstr = '['
         cch = ','
      ELSE
         cch = 'x'
      ENDIF

C --- Write the image size string...
      DO j=1,naxes
         i = INT(LOG10(FLOAT(axlen(j))))+1
         IF (i.LT.10) THEN
            WRITE(fmt,'((A),I1,(A))') '(I',i,')'
            WRITE(ctmp,fmt) axlen(j)
         ELSE
            WRITE(fmt,'((A),I2,(A))') '(I',i,')'
            WRITE(ctmp,fmt) axlen(j)
         ENDIF
         sizstr = sizstr(1:clen(sizstr))//ctmp(1:clen(ctmp))
         IF (j.LT.naxes) sizstr = sizstr(1:clen(sizstr))//cch
      ENDDO

C --- Return the result... 
      IF (styp.EQ.0) sizstr = sizstr(1:clen(sizstr))//']'

      RETURN
      END


