C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++   

      SUBROUTINE rjf_open (iunit, filename, lro, idbg, ierr)

C @(#)Subroutine: rjf_open           Author: R.A. Jansen -- May 28, 2009
C @(#)
C @(#)  Purpose: Open a named file 'filename' at specific logical device
C @(#)    unit 'iunit' for direct access in either read-only ('lro' = T)
C @(#)    or  read-write ('lro' = F)  mode.   For 'idbg' > 0, additional
C @(#)    messages may be printed.  If any error condition  is detected,
C @(#)    integer error status  'ierr'  will be non-zero upon exit.  Its
C @(#)    value (if >2000) uniquely identifies a known  error condition.
C @(#)    'rjf_open' is a wrapper around  'opendev'  with  FITS-specific
C @(#)    input variables. This allows us to hide some of the inner wor-
C @(#)    kings from the calling routine (typically MAIN).
C @(#)
C @(#)  Calling sequence:  CALL rjf_open (iunit,filename,lro,idbg,ierr),
C @(#)    where integer  'iunit'  is a  logical device unit  (possibly a
C @(#)    standard device), 'filename' is a character string of arbitra-
C @(#)    ry declared length, 'lro' is a boolean switch,  and 'idbg' and
C @(#)    'ierr' are both integers.
C @(#)
C @(#)  Dependencies:	clen, opendev; 'devices.inc'
C @(#)
C @(#)  Revision history:
C @(#)    Jul  1, 2009 [RAJ] -- Fixed bug of possibly negative 'iunit'.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Learn about default devices...
      INCLUDE	'devices.inc'

C --- Declaration of input/return variables...
      CHARACTER*(*) filename
      INTEGER	iunit, idbg, ierr
      LOGICAL	lro

C --- Declaration of local variables...
      CHARACTER	dbid*19, actype*8, acmode*8
      INTEGER	reclen, clen

C     ------------------------------------------------------------------

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C     Initialize the debugging ID string...
      dbid  = 'DEBUG(rjf_open): '

C     Return for a blank or empty file file name string...
      IF (clen(filename).EQ.0) THEN
         IF (idbg.GT.0) WRITE(*,*)
     +      dbid//'file name is blank or undefined ("") on input.'
         ierr = 2001
         RETURN
      ENDIF

C     Return for 'iunit' that is illegal or matches a reserved device...
      IF (iunit.LT.0) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//'specified logical device '//
     +      'unit number is illegal (',iunit,'< 0).'
         ierr = 2002
      ELSE IF (iunit.EQ.STDIN) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//
     +      'specified logical device unit number matches STDIN.'
         ierr = 2003
      ELSE IF (iunit.EQ.STDOUT) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//
     +      'specified logical device unit number matches STDOUT.'
         ierr = 2004
      ELSE IF (iunit.EQ.STDERR) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//
     +      'specified logical device unit number matches STDERR.'
         ierr = 2005
      ENDIF
      IF (ierr.NE.0) RETURN

C --- Initialize file access mode variables...
      IF (lro) THEN
         acmode = 'read    '
      ELSE
         acmode = 'write   '
      ENDIF
      actype = 'direct  '
      reclen = 2880

C --- Open the named file (if it exists) at the specified logical device
C     unit for direct access in read-only or read-write mode. 'opendev'
C     handles error messaging internally (returning 'ierr'=0 if success-
C     ful, or 'ierr'=1 if not) ...
      CALL opendev(iunit,filename,acmode,actype,reclen,ierr)
      IF (ierr.NE.0) ierr = 2006


      RETURN
      END


